# generate-date-image
Creates an image called image.png containing the current date

## Installation
`pip install generatedateimage`
## Usage
```
>>> from generatedateimage import generatedateimage
>>> generatedateimage.generateDateImage()

```
